@@ -2,7 +2,7 @@
 /*
  *  Authors: Iain Holmes <iain@ximian.com>
  *
- *  Copyright 2002 Ximain, Inc. (www.ximian.com)
+ *  Copyright 2002 Iain Holmes 
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,11 +35,9 @@ static char *
 make_fullname (const char *theme_name,
 	       const char *name)
 {
-	char *loc, *image;
+	char *image;
 
-	loc = g_concat_dir_and_file (theme_name, name);
-	image = g_concat_dir_and_file (THEME_DIR, loc);
-	g_free (loc);
+	image = g_build_filename (THEME_DIR, theme_name, name, NULL);
 
 	return image;
 }
@@ -127,8 +125,7 @@ theme_load (GnomeCD *gcd,
 	g_return_val_if_fail (gcd != NULL, NULL);
 	g_return_val_if_fail (theme_name != NULL, NULL);
 
-	g_print ("HEllo theme world\n");
-	theme_path = g_concat_dir_and_file (THEME_DIR, theme_name);
+	theme_path = g_build_filename (THEME_DIR, theme_name, NULL);
 	if (g_file_test (theme_path, G_FILE_TEST_IS_DIR) == FALSE) {
 		/* Theme dir isn't a dir */
 
@@ -138,7 +135,7 @@ theme_load (GnomeCD *gcd,
 	}
 
 	tmp = g_strconcat (theme_name, ".theme", NULL);
-	xml_file = g_concat_dir_and_file (theme_path, tmp);
+	xml_file = g_build_filename (theme_path, tmp, NULL);
 	g_free (tmp);
 
 	if (g_file_test (xml_file,
@@ -152,7 +149,6 @@ theme_load (GnomeCD *gcd,
 		return NULL;
 	}
 
-	g_print ("Parsin file\n");
 	xml = xmlParseFile (xml_file);
 	g_free (xml_file);
 	
@@ -195,13 +191,10 @@ theme_load (GnomeCD *gcd,
 
 	while (ptr != NULL) {
 		if (xmlStrcmp (ptr->name, (const xmlChar *) "display") == 0) {
-			g_print ("Parsing display theme\n");
 			cd_display_parse_theme (gcd->display, theme, xml, ptr->xmlChildrenNode);
 		} else if (xmlStrcmp (ptr->name, (const xmlChar *) "icons") == 0) {
-			g_print ("Parsing widget theme\n");
 			parse_theme (theme, xml, ptr->xmlChildrenNode);
 		} else {
-			g_print ("Uknown element: %s\n", ptr->name);
 		}
 
 		ptr = ptr->next;
